pub fn is_curved_face(face: &BoundedPlane) -> boolExpand description
A radial face is a cylindrical patch, every other face of the compartment is flat
pub fn is_curved_face(face: &BoundedPlane) -> boolA radial face is a cylindrical patch, every other face of the compartment is flat